@@ -1,15 +1,13 @@
 import shlex
-from typing import Any
-from warnings import warn
 
 import xmltodict
 from kubernetes.dynamic.exceptions import ResourceNotFoundError
-from timeout_sampler import TimeoutExpiredError, TimeoutSampler
 
+from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
 from ocp_resources.node import Node
 from ocp_resources.pod import Pod
 from ocp_resources.resource import NamespacedResource
-from ocp_resources.utils.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES, TIMEOUT_5SEC, TIMEOUT_30SEC
+from timeout_sampler import TimeoutExpiredError, TimeoutSampler
 
 
 class VirtualMachineInstance(NamespacedResource):
@@ -21,13 +19,13 @@ class VirtualMachineInstance(NamespacedResource):
 
     class Status(NamespacedResource.Status):
         SCHEDULING = "Scheduling"
-        SCHEDULED = "Scheduled"
 
     def __init__(
         self,
         name=None,
         namespace=None,
         client=None,
+        privileged_client=None,
         yaml_file=None,
         delete_timeout=TIMEOUT_4MINUTES,
         **kwargs,
@@ -36,6 +34,7 @@ class VirtualMachineInstance(NamespacedResource):
             name=name,
             namespace=namespace,
             client=client,
+            privileged_client=privileged_client,
             yaml_file=yaml_file,
             delete_timeout=delete_timeout,
             **kwargs,
@@ -49,17 +48,8 @@ class VirtualMachineInstance(NamespacedResource):
             f"namespaces/{self.namespace}/virtualmachineinstances/{self.name}"
         )
 
-    def api_request(
-        self, method: str, action: str, url: str = "", retry_params: dict[str, int] | None = None, **params: Any
-    ) -> dict[str, Any]:
-        default_vmi_api_request_retry_params: dict[str, int] = {"timeout": TIMEOUT_30SEC, "sleep_time": TIMEOUT_5SEC}
-        return super().api_request(
-            method=method,
-            action=action,
-            url=url or self._subresource_api_url,
-            retry_params=retry_params or default_vmi_api_request_retry_params,
-            **params,
-        )
+    def api_request(self, method, action, **params):
+        return super().api_request(method=method, action=action, url=self._subresource_api_url, **params)
 
     def pause(self, timeout=TIMEOUT_4MINUTES, wait=False):
         self.api_request(method="PUT", action="pause")
@@ -79,14 +69,11 @@ class VirtualMachineInstance(NamespacedResource):
     def virt_launcher_pod(self):
         pods = list(
             Pod.get(
-                dyn_client=self.client,
+                dyn_client=self.privileged_client or self.client,
                 namespace=self.namespace,
                 label_selector=f"kubevirt.io=virt-launcher,kubevirt.io/created-by={self.instance.metadata.uid}",
             )
         )
-        if not pods:
-            raise ResourceNotFoundError(f"VIRT launcher POD not found for {self.kind}:{self.name}")
-
         migration_state = self.instance.status.migrationState
         if migration_state:
             #  After VM migration there are two pods, one in Completed status and one in Running status.
@@ -97,11 +84,13 @@ class VirtualMachineInstance(NamespacedResource):
         else:
             return pods[0]
 
+        raise ResourceNotFoundError(f"VIRT launcher POD not found for {self.kind}:{self.name}")
+
     @property
     def virt_handler_pod(self):
         pods = list(
             Pod.get(
-                dyn_client=self.client,
+                dyn_client=self.privileged_client or self.client,
                 label_selector="kubevirt.io=virt-handler",
             )
         )
@@ -152,14 +141,10 @@ class VirtualMachineInstance(NamespacedResource):
             TimeoutExpiredError: If resource not exists.
         """
         self.logger.info(f"Wait until {self.kind} {self.name} is {'Paused' if pause else 'Unpuased'}")
+        self.wait_for_domstate_pause_status(pause=pause, timeout=timeout)
         self.wait_for_vmi_condition_pause_status(pause=pause, timeout=timeout)
 
     def wait_for_domstate_pause_status(self, pause, timeout=TIMEOUT_4MINUTES):
-        warn(
-            message="wait_for_domstate_pause_status is deprecated and will be removed the next version.",
-            category=DeprecationWarning,
-            stacklevel=2,
-        )
         pause_status = "paused" if pause else "running"
         samples = TimeoutSampler(
             wait_timeout=timeout,
@@ -202,13 +187,13 @@ class VirtualMachineInstance(NamespacedResource):
             Node: Node
         """
         return Node(
-            client=self.client,
+            client=self.privileged_client or self.client,
             name=self.instance.status.nodeName,
         )
 
     def virsh_cmd(self, action):
         return shlex.split(
-            f"virsh {self.virt_launcher_pod_hypervisor_connection_uri} {action} {self.namespace}_{self.name}"
+            "virsh" f" {self.virt_launcher_pod_hypervisor_connection_uri} {action} {self.namespace}_{self.name}"
         )
 
     def get_xml(self):
@@ -274,11 +259,6 @@ class VirtualMachineInstance(NamespacedResource):
         Returns:
             String: VMI Status as string
         """
-        warn(
-            message="get_domstate is deprecated and will be removed the next version.",
-            category=DeprecationWarning,
-            stacklevel=2,
-        )
         return self.execute_virsh_command(command="domstate")
 
     def get_dommemstat(self):
